pub struct SendAddRequest {
pub name: String,
pub notes: Option<String>,
pub view_type: SendViewType,
pub max_access_count: Option<u32>,
pub disabled: bool,
pub hide_email: bool,
pub deletion_date: DateTime<Utc>,
pub expiration_date: Option<DateTime<Utc>>,
pub auth: SendAuthType,
}Expand description
Request model for creating a new Send.
Fields
name: StringThe name of the Send.
notes: Option<String>Optional notes visible to the sender.
view_type: SendViewTypeThe type and content of the Send.
max_access_count: Option<u32>Maximum number of times the Send can be accessed.
disabled: boolWhether the Send is disabled and cannot be accessed.
hide_email: boolWhether to hide the sender’s email from recipients.
deletion_date: DateTime<Utc>Date and time when the Send will be permanently deleted.
expiration_date: Option<DateTime<Utc>>Optional date and time when the Send expires and can no longer be accessed.
auth: SendAuthTypeAuthentication method for accessing this Send.