pub struct SendView {Show 19 fields
pub id: Option<SendId>,
pub access_id: Option<String>,
pub name: String,
pub notes: Option<String>,
pub key: Option<String>,
pub new_password: Option<String>,
pub has_password: bool,
pub type: SendType,
pub file: Option<SendFileView>,
pub text: Option<SendTextView>,
pub max_access_count: Option<u32>,
pub access_count: u32,
pub disabled: bool,
pub hide_email: bool,
pub revision_date: DateTime<Utc>,
pub deletion_date: DateTime<Utc>,
pub expiration_date: Option<DateTime<Utc>>,
pub emails: Vec<String>,
pub auth_type: AuthType,
}Fields
id: Option<SendId>access_id: Option<String>name: Stringnotes: Option<String>key: Option<String>Base64 encoded key
new_password: Option<String>Replace or add a password to an existing send. The SDK will always return None when
decrypting a Send
TODO: We should revisit this, one variant is to have [Create, Update]SendView DTOs.
has_password: boolDenote if an existing send has a password. The SDK will ignore this value when creating or updating sends.
type: SendTypefile: Option<SendFileView>text: Option<SendTextView>max_access_count: Option<u32>access_count: u32disabled: boolhide_email: boolrevision_date: DateTime<Utc>deletion_date: DateTime<Utc>expiration_date: Option<DateTime<Utc>>emails: Vec<String>Email addresses for OTP authentication.
Note: Mutually exclusive with new_password. If both are set, only password
authentication will be used. When creating or editing sends, use crate::SendAuthType
to ensure mutual exclusivity at the type level.
auth_type: AuthTypeTrait Implementations
Sourceimpl<UT> ConvertError<UT> for SendView
impl<UT> ConvertError<UT> for SendView
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<'de> Deserialize<'de> for SendView
impl<'de> Deserialize<'de> for SendView
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<UT> FfiConverter<UT> for SendView
impl<UT> FfiConverter<UT> for SendView
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a [MetadataBuffer].
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl FromWasmAbi for SendViewwhere
Self: DeserializeOwned,
impl FromWasmAbi for SendViewwhere
Self: DeserializeOwned,
Sourceimpl IdentifyKey<SymmetricKeySlotId> for SendView
impl IdentifyKey<SymmetricKeySlotId> for SendView
fn key_identifier(&self) -> SymmetricKeySlotId
Sourceimpl IntoWasmAbi for &SendView
impl IntoWasmAbi for &SendView
Sourceimpl IntoWasmAbi for SendView
impl IntoWasmAbi for SendView
Sourceimpl<UT> LiftReturn<UT> for SendView
impl<UT> LiftReturn<UT> for SendView
Sourcetype ReturnType = <SendView as Lift<UT>>::FfiType
type ReturnType = <SendView as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
fn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
fn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> LowerError<UT> for SendView
impl<UT> LowerError<UT> for SendView
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for SendView
impl<UT> LowerReturn<UT> for SendView
Sourcetype ReturnType = <SendView as Lower<UT>>::FfiType
type ReturnType = <SendView as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
fn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl OptionFromWasmAbi for SendViewwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for SendViewwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for SendView
impl OptionIntoWasmAbi for SendView
Sourceimpl RefFromWasmAbi for SendViewwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for SendViewwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourceimpl Tsify for SendView
impl Tsify for SendView
const DECL: &'static str = "export interface SendView {\n id: SendId | undefined;\n accessId: string | undefined;\n name: string;\n notes: string | undefined;\n /**\n * Base64 encoded key\n */\n key: string | undefined;\n /**\n * Replace or add a password to an existing send. The SDK will always return None when\n * decrypting a [Send]\n * TODO: We should revisit this, one variant is to have `[Create, Update]SendView` DTOs.\n */\n newPassword: string | undefined;\n /**\n * Denote if an existing send has a password. The SDK will ignore this value when creating or\n * updating sends.\n */\n hasPassword: boolean;\n type: SendType;\n file: SendFileView | undefined;\n text: SendTextView | undefined;\n maxAccessCount: number | undefined;\n accessCount: number;\n disabled: boolean;\n hideEmail: boolean;\n revisionDate: DateTime<Utc>;\n deletionDate: DateTime<Utc>;\n expirationDate: DateTime<Utc> | undefined;\n /**\n * Email addresses for OTP authentication.\n * **Note**: Mutually exclusive with `new_password`. If both are set, only password\n * authentication will be used. When creating or editing sends, use [crate::SendAuthType]\n * to ensure mutual exclusivity at the type level.\n */\n emails: string[];\n authType: AuthType;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for SendViewwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for SendViewwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for SendView
impl VectorIntoWasmAbi for SendView
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for SendView
impl WasmDescribeVector for SendView
impl StructuralPartialEq for SendView