pub struct SendClient {
pub(crate) client: Client,
}Fields
client: ClientImplementations
Sourceimpl SendClient
impl SendClient
fn new(client: Client) -> Self
pub fn decrypt(&self, send: Send) -> Result<SendView, SendDecryptError>
pub fn decrypt_list( &self, sends: Vec<Send>, ) -> Result<Vec<SendListView>, SendDecryptError>
pub fn decrypt_file( &self, send: Send, encrypted_file_path: &Path, decrypted_file_path: &Path, ) -> Result<(), SendDecryptFileError>
pub fn decrypt_buffer( &self, send: Send, encrypted_buffer: &[u8], ) -> Result<Vec<u8>, SendDecryptError>
pub fn encrypt(&self, send_view: SendView) -> Result<Send, SendEncryptError>
pub fn encrypt_file( &self, send: Send, decrypted_file_path: &Path, encrypted_file_path: &Path, ) -> Result<(), SendEncryptFileError>
pub fn encrypt_buffer( &self, send: Send, buffer: &[u8], ) -> Result<Vec<u8>, SendEncryptError>
Sourceimpl SendClient
impl SendClient
pub(crate) fn get_repository( &self, ) -> Result<Arc<dyn Repository<Send>>, RepositoryError>
Sourceimpl SendClient
impl SendClient
Sourcepub async fn create(
&self,
request: SendAddRequest,
) -> Result<SendView, CreateSendError>
pub async fn create( &self, request: SendAddRequest, ) -> Result<SendView, CreateSendError>
Create a new Send and save it to the server.
Sourceimpl SendClient
impl SendClient
Sourcepub async fn edit(
&self,
send_id: SendId,
request: SendEditRequest,
) -> Result<SendView, EditSendError>
pub async fn edit( &self, send_id: SendId, request: SendEditRequest, ) -> Result<SendView, EditSendError>
Edit the Send and save it to the server.
Sourceimpl SendClient
impl SendClient